@@ -32,7 +32,6 @@ import org.apache.commons.logging.LogFactory;
 import org.apache.http.Header;
 import org.apache.http.HttpHost;
 import org.apache.http.HttpRequest;
-import org.apache.http.annotation.NotThreadSafe;
 import org.apache.http.auth.AUTH;
 import org.apache.http.auth.AuthenticationException;
 import org.apache.http.auth.Credentials;
@@ -67,7 +66,6 @@ import com.sun.jna.ptr.IntByReference;
  *
  * @since 4.4
  */
-@NotThreadSafe
 public class WindowsNegotiateScheme extends AuthSchemeBase {
 
     private final Log log = LogFactory.getLog(getClass());
@@ -243,6 +241,15 @@ public class WindowsNegotiateScheme extends AuthSchemeBase {
         final String spn;
         if (this.servicePrincipalName != null) {
             spn = this.servicePrincipalName;
+        } else if(isProxy()){
+            final HttpClientContext clientContext = HttpClientContext.adapt(context);
+            final RouteInfo route = clientContext.getHttpRoute();
+            if (route != null) {
+                spn = "HTTP/" + route.getProxyHost().getHostName();
+            } else {
+                // Should not happen
+                spn = null;
+            }
         } else {
             final HttpClientContext clientContext = HttpClientContext.adapt(context);
             final HttpHost target = clientContext.getTargetHost();
